-- Collision groups:
-- 0x1 - top and bottom walls
-- 0x2 - player
-- 0x4 - enemies
-- 0x8 - side walls
-- 0x10 - bullets
import "CoreLibs/object"
import "CoreLibs/graphics"
import "CoreLibs/sprites"
import "CoreLibs/timer"
import "kani"
import "enemy/ika"
import "enemy/ebi"

local gfx <const> = playdate.graphics

local player = nil
local ui = nil

function setup()
   ui = UI()
   player = Kani(ui)
   player:moveTo(16, 120)
   player:addInputHandlers()
   player:add()
   ui:add()

   local enemy = Ika()
   enemy:moveTo(350, 120)
   enemy:add()

   enemy = Ebi()
   enemy:moveTo(270, 50)
   enemy:add()

   enemy = Ebi()
   enemy:moveTo(280, 100)
   enemy:add()

   enemy = Ebi()
   enemy:moveTo(290, 150)
   enemy:add()

   enemy = Ebi()
   enemy:moveTo(300, 200)
   enemy:add()

   makeWalls()
   
   drawBackground()
end

function makeWalls()
   makeWall(200, 0, 400, 1, 0x1)
   makeWall(0, 120, 1, 240, 0x8)
   makeWall(200, 240, 400, 1, 0x1)
   makeWall(400, 120, 1, 240, 0x8)
end

function makeWall(x, y, w, h, mask)
   local wall = gfx.sprite.new()
   wall:setSize(w, h)
   wall:setCollideRect(0, 0, wall:getSize())
   wall:moveTo(x, y)
   wall:setGroupMask(mask)
   wall:add()
end

function drawBackground()
   local backgroundImage = gfx.image.new(400, 240, gfx.kColorWhite)
   gfx.sprite.setBackgroundDrawingCallback(
      function(x, y, width, height)
         backgroundImage:draw(0, 0)
      end
   )
end

function playdate.update()
   gfx.sprite.update()
   playdate.timer.updateTimers()
end

setup()
